// SPDX-License-Identifier: BSD-3-Clause
pragma solidity ^0.8.4;

import "@openzeppelin/contracts/token/ERC20/ERC20.sol";

contract NativeXClaimFree is ERC20 {

    address private contractOwner;
    string public NativeX = "ClaimFree";

    function decimals() public pure override returns (uint8) {
        return 0;
    }

    modifier onlyContractOwner {
        require(contractOwner == msg.sender, "You are not the contract owner.");
        _;
    }

    constructor(string memory _name, string memory _symbol) ERC20(_name, _symbol) {
        contractOwner = msg.sender;
    }

    receive() external payable {
        getFreeToken();
    }

    function getFreeToken() public {
        _mint(msg.sender, 1);
    }
    
    function createSendTokens(address _to, uint256 _count) public onlyContractOwner {
        _mint(_to, _count);
    }

    function createHoldTokens(uint256 _count) public onlyContractOwner {
        _mint(contractOwner, _count);
    }
    
    function burnTokens(uint256 _tokens) public {
        _burn(msg.sender, _tokens);
    }

    function transferContractOwner(address _newOwner) public {
        require(msg.sender == contractOwner, "Only the contract owner can use this function.");
        contractOwner = _newOwner;
    }

    function withdrawNativeAmt(uint256 _native_tokens) public onlyContractOwner {
        if(address(this).balance > _native_tokens * 1 ether){
            (bool success, ) = contractOwner.call{value: _native_tokens * 1 ether}("");
            require(success, "You cannot withdraw the contract's native tokens at this time.");
        } else {
            withdrawAllNative();
        }
    }

    function withdrawAllNative() public onlyContractOwner {
        (bool success,) = contractOwner.call{ value: address(this).balance }("");
        require(success, "You cannot withdraw this contract's native tokens at this time.");
    }

}
